Module: Aef
- Defined in:
- lib/aef/migrator.rb
Overview
Namespace for projects of Alexander E. Fischer [email protected]
If you want to be able to simply type Example instead of Aef::Example to address classes in this namespace simply write the following before using the classes:
include Aef
Defined Under Namespace
Classes: Migrator